@@ -44,13 +44,12 @@ class CommittedFileSizeCheck(CommittedFileCheck):
         else:
             not_ignore = False
         not_framework = self.committed_file.get_framework()
-        if file_size == -1:
+        if not_ignore and file_size == -1:
             yield (
                 Severity.ERROR,
                 '提交 {} 的文件 {} 无法识别大小'.format(
                     self.committed_file.commit, self.committed_file.path)
             )
-        print(extension, not_ignore, not_framework)
         if not_ignore and not_framework and file_size >= config.get("commit_check.commit_file_max_size"):
             yield (
                 Severity.ERROR,
@@ -75,7 +74,7 @@ class CommittedFileExtensionCheck(CommittedFileCheck):
         extension = self.committed_file.get_extension()
         if extension in illegal_suffixes_list:
             yield (
-                Severity.ERROR,
+                Severity.WARNING,
                 '提交 {} 的文件 {} 在不允许的提交文件后缀名清单中 {}'.format(
                     self.committed_file.commit,
                     self.committed_file.path,
